<?php

namespace Teknisa\SM\Service;

use Doctrine\ORM\EntityManager;
use Teknisa\SM\Factory\IntegracaoTecfoodFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\Session\Session;
use Teknisa\SM\Service\IntegracoesTeknisaService;

class IntegracaoTecfoodService {

    protected $integracaoFactory;
    protected $environment;
    protected $newCode;
    protected $session;
    protected $connection;
    protected $integracoesTeknisaService;

    public function __construct(EntityManager $entityManager, IntegracaoTecfoodFactory $integracaoFactory, Environment $environment, NewCode $newCode, Session $session, IntegracoesTeknisaService $integracoesTeknisaService) {
        $this->connection                = $entityManager->getConnection();
        $this->integracaoFactory         = $integracaoFactory;
        $this->environment               = $environment;
        $this->newCode                   = $newCode;
        $this->session                   = $session;
        $this->integracoesTeknisaService = $integracoesTeknisaService;
    }

    /**
     * Retorna a URL de integração com o Tecfood.
     * 
     * @param integer $nrorg
     * 
     * @return string
     */
    public function getUrlIntegracaoTecfood($nrorg) {
        $params = array(
            "NRORG" => $nrorg
        );
        
        $dataset = $this->integracaoFactory->getUrlIntegracaoTecfood($params);
        return $dataset[0]["URLINTEGRACAOTECFOOD"];
    }
  
    /**
     * Verifica se o contrato utiliza a integração com o FM.
     * 
     * @param integer $nrseqcontrato
     * @param integer $nrorg
     * 
     * @return mixed[]
     */
    public function verificarUtilizaIntegracao($nrseqcontrato, $nrorg) {

        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG" => $nrorg
        );
        
        $dataset = $this->integracaoFactory->verificarUtilizaIntegracao($params);

        $utilizaInt = $dataset[0]["IDINTEGRACAOTECFOOD"];

        return $utilizaInt;
    }

    /**
     * Retorna o tipo de local para integração dos locais de atendimento.
     * 
     * @param integer $nrorg
     * 
     * @return string
     */
    public function getTipoServicoIntegracaoTecfood($nrseqcontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG" => $nrorg
        );
        
        $dataset = $this->integracaoFactory->getTipoServicoIntegracaoTecfood($params);
        return $dataset[0]["IDTIPOSERVINTTECFOOD"];
    }

    /**
     * Retorna os dados de local para integração dos locais de atendimento.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getDadosLocais($nrseqcontrato, $nrorg) {

        $params = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG" => $nrorg
        );
        
        $dataset = $this->integracaoFactory->getDadosLocais($params);
        return $dataset;
    }

    public function integrarServicos($nrseqcontrato, $nrorg, $operador, $tipoServicoIntegracao, $URLIntegracaoTecfood) {
        try{

            $validaPadrServ = $this->integracaoFactory->validaPadrServ();
            if ($validaPadrServ > 0) {
                $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG" => $nrorg
                );
                $servicos = $this->integracaoFactory->getDadosServicos($params);

                if (count($servicos) != 0){ 

                    $dadosAux = array();

                    foreach($servicos as $ind => $servico){

                        if ($servico["CDFILIAL"] != null) {

                            /*Valida se for informado o grupo de serviço. Caso não tenha sido, são feitas as seguintes validações

                            1 - Tenta pegar o primeiro grupo de serviço inserido como padrão
                            2 - Se nhão houver nenhum grupo de serviço na base, insere o Grupo de serviço "001 - Padrão" e utiliza esse grupo de serviço.

                            */
                            if ($servico["CDGRUPSERVINTTECFOOD"] == null){
                                $valGrupserv = $this->integracaoFactory->getGrupServ();
                                if (count($valGrupserv)!= 0){
                                    $grupServInt = $valGrupserv[0]["CDGRUPSERV"];
                                }
                                else{

                                    $params = array(
                                        "NRORG" => $nrorg,
                                        "CDOPERADOR" => $operador
                                    );

                                    $grupServInt =  $this->integracaoFactory->insereGrupServPadrao($params);
                                } 
                            }
                            else{
                                $grupServInt = $servico["CDGRUPSERVINTTECFOOD"];
                            }

                            /*Valida se for informado o horário para início de preparo. Caso não tenha sido, é considerado '0000'*/
                            if ($servico["HRINIPREPSERVINTTECFOOD"] == null){
                                $hrIniPrepServ = '0000';
                            }
                            else{
                                $hrIniPrepServ = str_replace(':', '', $servico["HRINIPREPSERVINTTECFOOD"]);
                            }

                            /*Prepara os dados para inserção do serviço*/
                            $dadosAux[$ind] = array(
                                "CDFILIAL"   => $servico["CDFILIAL"], 
                                "CDSERVFILI"   => $servico["CDSERVORCA"],
                                "NMSERVICO"   => $servico["NMSERVORCA"], 
                                "CDGRUPSERV"   => $grupServInt, 
                                "HRINICATEN"   => $hrIniPrepServ, 
                                "CDPRODUTO"   => $servico["CDPRODFATSERV"], 
                                "IDTIPOSERV"  => $tipoServicoIntegracao,
                                "NRORG"          => $nrorg,
                                "CDOPERADOR"     => $operador,
                                "NRITEMOCONTRATO" => $servico["NRITEMOCONTRATO"],
                                "NRSEQCONTRATO" => $servico["NRSEQCONTRATO"],
                                "NRESTRUTURAM" => $servico["NRESTRUTURAM"]

                            );
                        }
                    }

                    /*
                    Rotina já preparada para receber o webservice, porém, como deve ser feita no TECFOOD, por hora, será utilizada a função "inserirServicos";
                    $dados = array(
                        "requestType" => "DataSet",
                        "dataset"     => array($dadosAux)
                    );

                    
                    $retorno = $this->integracoesTeknisaService->executarCurl(null, $URLIntegracaoTecfood."<nome da rota>", $dados);
                    */
                    if (count($dadosAux) != 0){
                        $retorno = $this->inserirServicos($dadosAux);
                    }
                    
                }
                else {

                    $retorno = 'OK';
                }
            }
            else {
                $retorno = 'Operação Bloqueda. Não é permitida a integração dos Serviços do "SM" para o "Tecfood", pois existe um "Padrão de Serviços" definido no Tecfood.';
            }

            return $retorno;
        }
        catch (\Exception $e) {

            return $e->getMessage();
        }
    }

    public function inserirServicos($dados){
        $this->connection->beginTransaction();
        try{
            
            $dadoslog = array();
            foreach($dados as $ind => $dado){

                $params = array(
                        "CDFILIAL"   =>$dado["CDFILIAL"],
                        "CDSERVFILI"   =>$dado["CDSERVFILI"]              
                );

                $validaExistServ = $this->integracaoFactory->validaExisteServico($params);

                if ($validaExistServ == 0) {
                    $params = array(
                        "CDFILIAL"   =>$dado["CDFILIAL"],
                        "CDSERVFILI"   =>$dado["CDSERVFILI"],
                        "NMSERVICO"   =>$dado["NMSERVICO"], 
                        "CDGRUPSERV"   =>$dado["CDGRUPSERV"], 
                        "HRINICATEN"   =>$dado["HRINICATEN"], 
                        "CDPRODUTO"   =>$dado["CDPRODUTO"], 
                        "IDTIPOSERV"  =>$dado["IDTIPOSERV"],
                        "NRORG"          =>$dado["NRORG"],
                        "CDOPERADOR"     =>$dado["CDOPERADOR"]              
                    );


                    $this->integracaoFactory->insereServicos($params);
                }

                $params = array(
                    "CDFILIALTECFOOD" =>$dado["CDFILIAL"],
                    "CDSERVFILITECFOOD" =>$dado["CDSERVFILI"],
                    "NRITEMOCONTRATO" => $dado["NRITEMOCONTRATO"],
                    "NRORG" => $dado["NRORG"]
                );

                $this->integracaoFactory->updataItensContrato($params);


                $dadoslog[$ind] = array(
                    "NRSEQCONTRATO" => $dado["NRSEQCONTRATO"],
                    "NRITEMOCONTRATO" => $dado["NRITEMOCONTRATO"],
                    "NRESTRUTURAM" => $dado["NRESTRUTURAM"],
                    "NRORG"          =>$dado["NRORG"],
                    "CDOPERADOR"     =>$dado["CDOPERADOR"]  
                );

            }

            $this->inserelog($dadoslog, 'Cadastro de Serviço','Integração realizada com sucesso');
            $this->connection->commit();
            return "OK";
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            return $e->getMessage();
        }
    }


    public function integrarCliFilial($nrseqcontrato, $nrorg, $operador, $URLIntegracaoTecfood) {
        try{

            $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG" => $nrorg
                );

            $servicos = $this->integracaoFactory->getServicosInseridos($params);

            if (count($servicos) != 0){ 

                $dadosAux = array();

                foreach($servicos as $ind => $servico){

                        /*Prepara os dados para inserção do serviço*/
                        $dadosAux[$ind] = array(
                            "CDCLIENTE"   => $servico["CDCLIENTE"],
                            "CDFILIAL"   => $servico["CDFILIALTECFOOD"], 
                            "NRORG"          => $nrorg,
                            "CDOPERADOR"     => $operador,
                            "NRITEMOCONTRATO" => $servico["NRITEMOCONTRATO"],
                            "NRSEQCONTRATO" => $servico["NRSEQCONTRATO"],
                            "NRESTRUTURAM" => $servico["NRESTRUTURAM"]
                        );
                }
                /*
                    Rotina já preparada para receber o webservice, porém, como deve ser feita no TECFOOD, por hora, será utilizada a função "inserirClienFiliais";

                $dados = array(
                    "requestType" => "DataSet",
                    "dataset"     => array($dadosAux)
                );

                $retorno = $this->integracoesTeknisaService->executarCurl(null, $URLIntegracaoTecfood."<nome da rota>", $dados);
                */
                if (count($dadosAux) != 0){
                    $retorno = $this->inserirClienFiliais($dadosAux);
                }
                
            }
            else {

                $retorno = 'OK';
            }

            return $retorno;
        }
        catch (\Exception $e) {

            return $e->getMessage();
        }
    }

    public function inserirClienFiliais($dados){
        $this->connection->beginTransaction();
        try{
            
            $dadoslog = array();

            foreach($dados as $ind => $dado){
                $params = array(
                    "CDCLIENTE"   =>$dado["CDCLIENTE"],
                    "CDFILIAL"   =>$dado["CDFILIAL"]              
                );

                $validaExistServ = $this->integracaoFactory->validaExisteClienFilial($params);

                if ($validaExistServ == 0) {
                    $params = array(
                        "CDCLIENTE"   =>$dado["CDCLIENTE"],
                        "CDFILIAL"   =>$dado["CDFILIAL"],
                        "NRORG"          =>$dado["NRORG"],
                        "CDOPERADOR"     =>$dado["CDOPERADOR"]              
                    );

                    $this->integracaoFactory->insereClienFilial($params);
                }

                $dadoslog[$ind] = array(
                    "NRSEQCONTRATO" => $dado["NRSEQCONTRATO"],
                    "NRITEMOCONTRATO" => $dado["NRITEMOCONTRATO"],
                    "NRESTRUTURAM" => $dado["NRESTRUTURAM"],
                    "NRORG"          =>$dado["NRORG"],
                    "CDOPERADOR"     =>$dado["CDOPERADOR"]  
                );
            }

            $this->inserelog($dadoslog, 'Clientes por Filial','Integração realizada com sucesso');
            $this->connection->commit();

            return "OK";
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            return $e->getMessage();
        }
    }

    public function integrarCliServ($nrseqcontrato, $nrorg, $operador, $URLIntegracaoTecfood) {
        try{

            $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRORG" => $nrorg
                );

            $servicos = $this->integracaoFactory->getServicosInseridos($params);

            if (count($servicos) != 0){ 

                $dadosAux = array();

                foreach($servicos as $ind => $servico){

                        /*Prepara os dados para inserção do serviço*/
                        $dadosAux[$ind] = array(
                            "CDCLIENTE"   => $servico["CDCLIENTE"],
                            "CDFILIAL"   => $servico["CDFILIALTECFOOD"], 
                            "CDSERVFILI" => $servico["CDSERVFILITECFOOD"],
                            "VRSERVFATHIS" => $servico["VRTOTITEMCOMDESC"], 
                            "NRORG"          => $nrorg,
                            "CDOPERADOR"     => $operador,
                            "NRITEMOCONTRATO" => $servico["NRITEMOCONTRATO"],
                            "NRSEQCONTRATO" => $servico["NRSEQCONTRATO"],
                            "NRESTRUTURAM" => $servico["NRESTRUTURAM"]
                        );
                }

                /*
                Rotina já preparada para receber o webservice, porém, como deve ser feita no TECFOOD, por hora, será utilizada a função "inserirClienServicos";

                $dados = array(
                    "requestType" => "DataSet",
                    "dataset"     => array($dadosAux)
                );

                
                $retorno = $this->integracoesTeknisaService->executarCurl(null, $URLIntegracaoTecfood."<nome da rota>", $dados);
                */

                if (count($dadosAux) != 0){
                    $retorno = $this->inserirClienServicos($dadosAux);
                }
                
            }
            else {

                $retorno = 'OK';
            }

            return $retorno;
        }
        catch (\Exception $e) {

            return $e->getMessage();
        }
    }

    public function inserirClienServicos($dados){
        $this->connection->beginTransaction();
        try{
            $dadoslog = array();
            foreach($dados as $ind => $dado){

                $params = array(
                    "CDCLIENTE"   => $dado["CDCLIENTE"],
                    "CDFILIAL"   => $dado["CDFILIAL"],
                    "CDSERVFILI" => $dado["CDSERVFILI"]             
                );

                $validaExistServ = $this->integracaoFactory->validaExisteServClie($params);

                if ($validaExistServ == 0) {

                    $params = array(
                        "CDCLIENTE"   => $dado["CDCLIENTE"],
                        "CDFILIAL"   => $dado["CDFILIAL"],
                        "CDSERVFILI" => $dado["CDSERVFILI"],
                        "NRORG"      => $dado["NRORG"],
                        "CDOPERADOR" => $dado["CDOPERADOR"]              
                    );

                    $this->integracaoFactory->insereServClie($params);

                    $params = array(
                        "CDCLIENTE"    => $dado["CDCLIENTE"],
                        "CDFILIAL"     => $dado["CDFILIAL"],
                        "CDSERVFILI"   => $dado["CDSERVFILI"],
                        "VRSERVFATHIS" => $dado["VRSERVFATHIS"],
                        "NRORG"        => $dado["NRORG"],
                        "CDOPERADOR"   => $dado["CDOPERADOR"]              
                    );

                    $this->integracaoFactory->insereHistServFatu($params);
                }

                $dadoslog[$ind] = array(
                    "NRSEQCONTRATO" => $dado["NRSEQCONTRATO"],
                    "NRITEMOCONTRATO" => $dado["NRITEMOCONTRATO"],
                    "NRESTRUTURAM" => $dado["NRESTRUTURAM"],
                    "NRORG"          =>$dado["NRORG"],
                    "CDOPERADOR"     =>$dado["CDOPERADOR"]  
                );

            }

            $this->inserelog($dadoslog, 'Clientes por Serviço','Integração realizada com sucesso');
            $this->connection->commit();

            return 'OK';
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            return $e->getMessage();
        }
    }

    public function integraServicosTecfood($nrseqcontrato) {
        $nrorg = $this->environment->getNrOrg();
        $operador = $this->environment->getCdOperador();
        $dadoslog = array();

        try{
            $validaIntegracaoTecfood = $this->verificarUtilizaIntegracao($nrseqcontrato, $nrorg);
            $URLIntegracaoTecfood = $this->getUrlIntegracaoTecfood($nrorg);
            $tipoServicoIntegracao = $this->getTipoServicoIntegracaoTecfood($nrseqcontrato, $nrorg);

            if ($validaIntegracaoTecfood == 'S') {
                if ($URLIntegracaoTecfood != null) {
                    if ($tipoServicoIntegracao != null) {
                        $retornoServ = $this->integrarServicos($nrseqcontrato, $nrorg, $operador, $tipoServicoIntegracao, $URLIntegracaoTecfood);
                        if($retornoServ == 'OK'){

                            $retornoCliFilial = $this->integrarCliFilial($nrseqcontrato, $nrorg, $operador, $URLIntegracaoTecfood);

                            if ($retornoCliFilial == 'OK'){

                                $retornoCliServ = $this->integrarCliServ($nrseqcontrato, $nrorg, $operador, $URLIntegracaoTecfood);

                                if ($retornoCliServ == 'OK'){

                                    $retorno = 'OK';
                                }
                                else {

                                     $dadoslog[0] = array(
                                        "NRSEQCONTRATO" => $nrseqcontrato,
                                        "NRITEMOCONTRATO" => null,
                                        "NRESTRUTURAM" => null,
                                        "NRORG"          =>$nrorg,
                                        "CDOPERADOR"     =>$operador  
                                     );

                                     $retorno = 'Ocorreram erros na inserção de "Clientes por Serviço" do módulo "SM" para o módulo "Tecfood". Favor verificar o Log. Erro: '.$retornoCliServ;

                                     $this->inserelog($dadoslog, 'Clientes por Serviço', $retorno);
                                }
                            }
                            else{

                                $dadoslog[0] = array(
                                    "NRSEQCONTRATO" => $nrseqcontrato,
                                    "NRITEMOCONTRATO" => null,
                                    "NRESTRUTURAM" => null,
                                    "NRORG"          =>$nrorg,
                                    "CDOPERADOR"     =>$operador  
                                );

                                $retorno = 'Ocorreram erros na inserção de "Clientes por Filial" do módulo "SM" para o módulo "Tecfood". Favor verificar o Log. Erro: '.$retornoCliFilial;

                                $this->inserelog($dadoslog, 'Clientes por Filial', $retorno);
                            }
                        }
                        else {

                            $dadoslog[0] = array(
                                "NRSEQCONTRATO" => $nrseqcontrato,
                                "NRITEMOCONTRATO" => null,
                                "NRESTRUTURAM" => null,
                                "NRORG"          =>$nrorg,
                                "CDOPERADOR"     =>$operador  
                            );

                            $retorno = 'Ocorreram erros na inserção de "Serviços" do módulo "SM" para o módulo "Tecfood". Favor verificar o Log. Erro: '.$retornoServ;

                            $this->inserelog($dadoslog, 'Cadastro de Serviço', $retorno);
                        }
                    }
                    else {
                        $retorno = 'Não foi definido o tipo de serviço para integração dos serviços do módulo "SM" para o módulo "Tecfood". <br><br> Favor definir o parâmetro "Tipo de Serviço para Integração" na tela "Contrato".';
                    }
                }
                else {
                    $retorno = 'Não foi definida a URL para integração dos serviços do módulo "SM" para o módulo "Tecfood". <br><br> Favor definir o parâmetro "Url Integração (Tecfood)" na tela "Parametrização SM".';
                }
            }
            else {
                $retorno = 'OK';
            }

            return $retorno;
        }
        catch (\Exception $e) {
            return $e->getMessage();
        }
    }


    public function inserelog($dadoslog, $etapa, $motivo) {

        foreach($dadoslog as $log){

            $novoCodigo = $this->newCode->getCodeByTableName("FCT_LOGINTEGRATECFOOD", $log["NRORG"], 1, 10, true);

            $params = array(
                "NRLOGINTEGRATECFOOD" => $novoCodigo,
                "NRSEQCONTRATO" => $log["NRSEQCONTRATO"],
                "NRITEMOCONTRATO" => $log["NRITEMOCONTRATO"],
                "NRESTRUTURAM" => $log["NRESTRUTURAM"],
                "DSETAPA" => $etapa,
                "DSMOTIVO" => $motivo,
                "NRORG"          =>$log["NRORG"],
                "CDOPERADOR"     =>$log["CDOPERADOR"]  
            );

            $this->integracaoFactory->insereLogIntegraTecfood($params);
        }
    }
}

?>