<?php
namespace Teknisa\SM\Service;

use Doctrine\ORM\EntityManager;
use Teknisa\SM\Factory\Sm00004108RenovacaoContratoFactory;
use Teknisa\SM\Factory\Sm00004003ReajusteContratoFactory;
use Teknisa\SM\Factory\Sm00004000ContratoFactory;
use Teknisa\SM\Factory\IntegracaoOmFactory;
use Teknisa\SM\Service\Sm00004003ReajusteContratoService;
use Teknisa\SM\Service\IntegracoesTeknisaService;
use Teknisa\SM\Service\IntegracaoOmService;
use Teknisa\SM\Service\Sm00012000MedicaoFaturamentoService;
use Teknisa\SM\Service\Sm00004000ContratoService;
use Teknisa\SM\Util\Procedure\FctGerarParcelasFatura;
use Teknisa\SM\Util\Procedure\FctCancelarApuraMedicao;
use Teknisa\SM\Util\Procedure\FctCancelarMedicao;
use Teknisa\Libs\Util\NewCode;
use Teknisa\Libs\Util\ConnectionCustom;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\Environment;
use Teknisa\SM\Util\UtilContrato;
use Zeedhi\Framework\Session\Session;

class Sm00004108RenovacaoContratoService {
    protected $renovacaofactory;
    protected $entityManager;
    protected $connectioncustom;
    protected $connection;
    protected $reajusteService;
    
    public function __construct(Sm00004108RenovacaoContratoFactory $renovacaofactory, EntityManager $entityManager, ConnectionCustom $connectioncustom, Sm00004003ReajusteContratoService $reajusteService, NewCode $newCode,Sm00012000MedicaoFaturamentoService $medicaoService ) {
        $this->renovacaofactory = $renovacaofactory;
        $this->entityManager    = $entityManager;
        $this->connectioncustom = $connectioncustom;
        $this->reajusteService  = $reajusteService;
        $this->connection       = $entityManager->getConnection();
        $this->newCode          = $newCode;
        $this->medicaoService   = $medicaoService;
    }
    
    /**
     * Valida a conexão de uma determinada organização do SM
    **/
    public function getConnectionEntityManagerOrganizacaoSm($nrorg) {
        $entityManagerConnection = $this->connectioncustom->updateVpdConnection($nrorg);
        if($entityManagerConnection !== false)
            $this->entityManager = $entityManagerConnection;
        
        $this->connection = $this->entityManager->getConnection();
    }
    
    /**
     * Retorna todas as organizações que utilizam o SM
    **/
    public function getOrganizacoesSM() {
        $this->getConnectionEntityManagerOrganizacaoSm(20);
        $this->renovacaofactory = new Sm00004108RenovacaoContratoFactory($this->entityManager);
        
        return $this->renovacaofactory->getOrganizacoesSM();
    }
    
    /**
     * Valida a conexão e solicita a renovação automática dos contratos
    **/
    public function renovarContratosAutomaticamente($nrorg) {
        $this->getConnectionEntityManagerOrganizacaoSm($nrorg);
        $this->newCode          = new NewCode($this->connection, "NOVO_CODIGO_SC");
        $this->renovacaofactory = new Sm00004108RenovacaoContratoFactory($this->entityManager);
        
        $reajusteContratoFactory = new Sm00004003ReajusteContratoFactory($this->entityManager);
        $contratoFactory = new Sm00004000ContratoFactory($this->entityManager);
        $integracaoOmFactory = new IntegracaoOmFactory($this->entityManager);
        
        $session = new Session();
        $integracoesTeknisaService = new IntegracoesTeknisaService($session);
        $environment = new Environment($session);
        
        $integracaoOmService = new IntegracaoOmService($integracaoOmFactory, $environment, $session, $this->connectioncustom, $this->entityManager, $integracoesTeknisaService, null, null, null);
        
        $contratoService = new Sm00004000ContratoService($this->entityManager, $contratoFactory, $environment, null, null, null, null, $this->newCode, $integracaoOmService, null, $session, null);
        
        $this->reajusteService = new Sm00004003ReajusteContratoService($this->entityManager, $this->newCode, $reajusteContratoFactory, $contratoService, $contratoFactory, $integracaoOmService, $this->medicaoService);
        
        return $this->renovarContrato(array(), $nrorg, true, null, null, null, null, null, null, true);
    }
    
    /**
     * Realiza a renovação de um contrato.
     * 
     * @params{array} $nrseqcontrato - números dos contratos a ser reajustados.
     * Obs: Quando não enviado valor, a função faz a renovação automática dos contratos
    **/
    public function renovarContrato(array $contratos = array(), $nrorg, $idrenovautomatica, $dataIniVigencia = null, $nrdiasProrrog = null, $idreajustar = null, $cdoperador = null, $dataReajuste = null, $diasReajuste = null, $deveReajustar = false) {
        try {
            if ($idrenovautomatica) {
                $contratos = $this->renovacaofactory->getContratosVencidosComRenovacaoAutomatica($nrorg);
            }

            foreach($contratos as $contrato) {
                $this->connection->beginTransaction();
                $mensagemerror = null;
                
                //valores das datas para inserção na tabela FCT_PRORROGCONTRATO, chamada na função salvarProrrogContrato
                $params = array(
                    "NRSEQCONTRATO" => $contrato["NRSEQCONTRATO"] 
                );
                $datas = $this->renovacaofactory->getDatasAnterior($params);
                $dtAntInicialContrato = $datas[0]["DTINIVIGENCONT"];
                $dtAntFinalContrato = $datas[0]["DTFINVIGENCONT"];
                
                $codContrato = isset($contrato["NRCONTRATOFCT"]) ? ($contrato["NRCONTRATOFCT"] . " (" . $contrato["NRSEQCONTRATO"] . ")") : $contrato["NRSEQCONTRATO"];
                try {
                    if ($idrenovautomatica) {
                        $cdoperador    = $contrato["CDOPERULTATU"];
                        $idreajustar   = $contrato["IDREAJUSTEAUTOMATICO"] == "S";
                        $nrdiasProrrog = $contrato["NRDIASPRORGCONTRENOV"];
                        
                        $dataIniVigencia = DateUtil::getDataDeString($contrato["DTFINVIGENCONT"]);
                        $dataIniVigencia = DateUtil::adicionaIntervalo($dataIniVigencia, 1)->format("d/m/Y");
                    }
                    
                    $params = array(
                        "NRSEQCONTRATO"   => $contrato["NRSEQCONTRATO"],
                        "NRDIASPRORGCONT" => $nrdiasProrrog,
                        "DTINIVIGENCONT"  => $dataIniVigencia,
                        "NRORG"           => $nrorg
                    );
                    $nrseqprorrcont = $this->getNumeroProrrogContrato($nrorg);
                    if($idreajustar && $deveReajustar) {
                        $bloqueiaReajuste = $this->reajusteService->validaBloqReajusteContrIndividual($nrorg, $contrato["NRSEQCONTRATO"], $contrato["NRTIPOORCAMENTO"]);
                        if ($bloqueiaReajuste == "BLOQUEAR") {
                            throw new \Exception("Operação bloqueada!<br><br>Não será possível realizar o reajuste do contrato pois ele possui índices financeiros com o cadastro de alíquotas incompleto. Esses cadastros devem ser regularizados antes da realização dos reajustes dos contratos.");
                        }
                        else {
                            $result = $this->realizarReajusteContrato($contrato, $nrorg, $cdoperador, $nrseqprorrcont, $idrenovautomatica, $dataReajuste, $diasReajuste);
                            if($result)
                                throw new \Exception($result);
                        }
                        
                        if (!empty($dataReajuste)) {
                            //$dataReajusteContrato = DateUtil::getDataDeString($dataReajuste)->format("d/m/Y");
                            $dataReajusteContrato = explode(" ", $dataReajuste)[0];
                            
                            $params = array(
                                "NRSEQCONTRATO"         => $contrato["NRSEQCONTRATO"],
                                "NRORG"                 => $nrorg,
                                "DTPADREAJCONT"         => $dataReajusteContrato,
                                "NRDIASREAJAUTOMATICO"  => $diasReajuste
                            );
                            $this->renovacaofactory->alterarDadosReajusteContrato($params);
                        }
                    }
                    
                    $params = array(
                        "NRSEQCONTRATO"   => $contrato["NRSEQCONTRATO"],
                        "NRDIASPRORGCONT" => $nrdiasProrrog,
                        "DTINIVIGENCONT"  => $dataIniVigencia,
                        "NRORG"           => $nrorg
                    );
                    $this->renovacaofactory->alterarPeriodoVigenciaContrato($params);

                    $this->salvarProrrogContrato($contrato["NRSEQCONTRATO"], $dataIniVigencia, $nrdiasProrrog, $nrorg, $cdoperador, $idrenovautomatica,$nrseqprorrcont, $dtAntInicialContrato, $dtAntFinalContrato);
                    $procedure = new FctGerarParcelasFatura($this->connection);
                    $procedure->executar($contrato["NRSEQCONTRATO"], $nrorg, $cdoperador, 1);
                    $this->validarDuplicidadeFaturamento($contrato["NRSEQCONTRATO"], $dataIniVigencia, $nrorg, $cdoperador);
                    
                    
                    $this->reajusteService->refazerIntegracaoOM($contrato["NRSEQCONTRATO"], $nrorg);
                    
                    $this->connection->commit();
                    
                    if ($idrenovautomatica) {
                        // $msgReajuste = $idreajustar ? "SIM" : "NÃO";
                        $mensagemLog = "Período de vigência atualizado. ";
                        
                        echo "ORGANIZAÇÃO: " . $nrorg . " | Contrato " . $codContrato . " | SUCESSO: " . $mensagemLog . "\n";
                        
                        try {
                            $params = array (
                                "NRSEQCONTRATO"  => $contrato["NRSEQCONTRATO"],
                                "DTFINVIGENCONT" => $contrato["DTFINVIGENCONT"],
                                "DTINIVIGENCONT" => $contrato["DTINIVIGENCONT"],
                                "VRCONTRATO"     => $contrato["VRCONTRATO"],
                                "ERROR"          => null
                            );
                            
                            $this->renovacaofactory->inserirLogRenovacaoContrato($params);
                        }
                        catch(\Exception $e) {
                            echo "ORGANIZAÇÃO: " . $nrorg . " - Falha ao inserir log de sucesso do contrato " . $contrato["NRSEQCONTRATO"] . ": \n" . $e->getMessage();
                        }
                    }
                }
                catch (\Exception $e) {
                    $this->connection->rollback();
                    if (!$idrenovautomatica) {
                        throw $e;
                    }
                    else {
                        $mensagemerror = $e->getMessage();
                        echo "ORGANIZAÇÃO: " . $nrorg . " | Contrato " . $codContrato . " | ERRO: " . $mensagemerror . "\n";
                        
                        try {
                            $params = array (
                                "NRSEQCONTRATO"  => $contrato["NRSEQCONTRATO"],
                                "DTFINVIGENCONT" => $contrato["DTFINVIGENCONT"],
                                "DTINIVIGENCONT" => $contrato["DTINIVIGENCONT"],
                                "VRCONTRATO"     => $contrato["VRCONTRATO"],
                                "ERROR"          => $mensagemerror
                            );
                            
                            $this->renovacaofactory->inserirLogRenovacaoContrato($params);
                        }
                        catch(\Exception $e) {
                            echo "ORGANIZAÇÃO: " . $nrorg . " - Falha ao inserir log de erro do contrato " . $contrato["NRSEQCONTRATO"] . ": \n" . $e->getMessage();
                        }
                    }
                }
            }
            
            return $contratos;
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Realiza o reajuste de um contrato
    **/
    public function realizarReajusteContrato($contrato, $nrorg, $cdoperador, $nrseqprorrcont = null, $processoAutomatico = false, $dataReajuste = null, $diasReajuste = null) {
        $params = array(
            "NRSEQCONTRATO" => "_" . $contrato["NRSEQCONTRATO"] . "_",
            "NRORG"         => $nrorg
        );
        
        $paramsReajuste = $this->renovacaofactory->getParametrosReajusteContrato($params);
        if(count($paramsReajuste) == 0) {
            return "Parâmetros de reajuste não encontratos.";
        }
        else {
            if(!UtilContrato::validaPercentualIndiceFinanceiro($paramsReajuste)){
                return "A soma dos percentuais de utilização dos índices financeiros não está totalizando os 100% necessários para realização do reajuste deste contrato.";
            }

            $this->reajusteService->reajusteContrMassa($paramsReajuste, $cdoperador, true, $nrseqprorrcont, $processoAutomatico, $dataReajuste, $diasReajuste);
        }
        
        return null;
    }
    
    /**
     * Busca na tabela de parametrização geral se o sistema permite o envio de relatorios de renovação
    **/
    public function getParametrosGeracaoRelatorio($nrorg) {
        $paramgeral = $this->renovacaofactory->getParametrosGeracaoRelatorio($nrorg);
        return (count($paramgeral) == 1) ? $paramgeral[0] : null;
    }

    /**
     * deleta da tabela temporaria os logs e contratos que deram error
    **/
    public function deletarLogErroRenovacao($nrorg) {
        $params = array("NRORG" => $nrorg);
        $this->renovacaofactory->deletarLogErroRenovacao($params);
    }
    
    /**
     * Busca todos os contratos vencidos e que não possuem renovação automática
    **/
    public function getContratosSemRenovacaoAutomatica($nrorg, $tipoPeriodo) {
        $params = array(
            "PERIODO" => $tipoPeriodo,
            "NRORG"   => $nrorg
        );
        $dataset = $this->renovacaofactory->getContratosSemRenovacaoAutomatica($params);
        return (int)$dataset[0]["QTD"];
    }
    
    /**
     * Função privada utilizada para pegar o valor do PK da tabela FCT_PRORRORGCONTRATO
    */
    private function getNumeroProrrogContrato($nrorg){
        // $nrseqprorrcont = $this->newCode->getCodeByTableName("FCT_PRORROGCONTRATO", $nrorg, 1, 10, true);
        $nrseqprorrcont = $this->newCode->getCodeByTableName("NRSEQPRORRCONT", $nrorg, 1, 10, true);
        return $nrseqprorrcont ;
    }

    public function salvarProrrogContrato($nrseqcontrato, $dataIniVigencia, $nrdiasProrrog, $nrorg, $cdoperador, $idrenovautomatica,$nrseqprorrcont = null , $dtAntInicialContrato = null, $dtAntFinalContrato = null) {
        $msgRenovacaoAuto = $idrenovautomatica ? "automática" : "manual";
        $dsprorrcont = "Inserido pela rotina $msgRenovacaoAuto de Renovação de Contratos.";
        
        $dataFinalVigencia = DateUtil::getDataDeString($dataIniVigencia);
        $dataFinalVigencia = DateUtil::adicionaIntervalo($dataFinalVigencia, $nrdiasProrrog-1)->format("d/m/Y");
        
        $params = array(
            "NRSEQPRORRCONT"  => $nrseqprorrcont,
            "NRSEQCONTRATO"   => $nrseqcontrato,
            "IDPRORRCONT"     => "P",
            "DTNVDATAINICIAL" => $dataIniVigencia,
            "DTNVDATAFINAL"   => $dataFinalVigencia,
            "DSPRORRCONT"     => $dsprorrcont,
            "IDDTATIVO"       => "S",
            "NRORG"           => $nrorg,
            "NRORGINCLUSAO"   => $nrorg,
            "CDOPERINCLUSAO"  => $cdoperador,
            "IDATIVO"         => "S",
            "DTANTDTFINAL"    => $dtAntFinalContrato,
            "DTANTDTINICIAL"  => $dtAntInicialContrato
        );
        
        $this->renovacaofactory->salvarProrrogContrato($params);
    }
    
    /**
     * Altera os parâmetros "IDRENOVACAOAUTOMATICA" e "IDREAJUSTEAUTOMATICO" para os contratos selecionados
    **/
    public function salvarRenovReajAuto($nrseqcontrato, $idrenovacaoautomatica, $idreajusteautomatico, $nrorg, $cdoperador) {
       
        $contratos = explode('_', $nrseqcontrato);
        
        foreach($contratos as $contrato){
        
            $params = array(
                "IDRENOVACAOAUTOMATICA" => $idrenovacaoautomatica,
                "IDREAJUSTEAUTOMATICO"  => $idreajusteautomatico,
                "NRORG"                 => $nrorg,
                "OPERADOR"               => $cdoperador,
                "NRSEQCONTRATO"         => $contrato
            );
            
            $this->renovacaofactory->salvarRenovReajAuto($params);
        }
        
    }
    
    /**
     * Renova e reajusta os contratos selecionados
    **/
    public function renovContrMassa($contratos, $nrorg, $cdoperador) {
        try {
            $this->connection->beginTransaction();
            
            foreach($contratos as $contrato) {
                
                //valores das datas para inserção na tabela FCT_PRORROGCONTRATO, chamada na função salvarProrrogContrato
                $params = array(
                    "NRSEQCONTRATO" => $contrato["NRSEQCONTRATO"] 
                );
                $datas = $this->renovacaofactory->getDatasAnterior($params);
                $dtAntInicialContrato = $datas[0]["DTINIVIGENCONT"];
                $dtAntFinalContrato = $datas[0]["DTFINVIGENCONT"];
                
                /* Reajustar Contrato */ 
                if ($contrato["IDREAJUSTEAUTOMATICO"] == 'Y') {

                    $contr = array("NRSEQCONTRATO" => $contrato["NRSEQCONTRATO"]);
                    $result = $this->realizarReajusteContrato($contr, $nrorg, $cdoperador);
                    if($result) {
                        throw new \Exception($result);
                    }
                
                    unset($contr);
                }
                
                $dtIniRenovacao = explode(" ", $contrato["DTINIRENOVACAO"])[0];
                
                $params = array(
                    "NRSEQCONTRATO"   => $contrato["NRSEQCONTRATO"],
                    "NRDIASPRORGCONT" => $contrato["NRDIASRENOVACAO"],
                    "DTINIVIGENCONT"  => $dtIniRenovacao,
                    "NRORG"           => $nrorg
                );
                
                $this->renovacaofactory->alterarPeriodoVigenciaContrato($params);
                
                if (isset($contrato["DTPADREAJCONT"]) && !empty($contrato["DTPADREAJCONT"])) {
                    $dataReaj = explode(" ", $contrato["DTPADREAJCONT"])[0];

                    $params = array (
                        "NRSEQCONTRATO"         => $contrato["NRSEQCONTRATO"],
                        "NRORG"                 => $nrorg,
                        "DTPADREAJCONT"         => $dataReaj,
                        "NRDIASREAJAUTOMATICO"  => $contrato["NRDIASREAJAUTOMATICO"]
                    );
                    $this->renovacaofactory->alterarDadosReajusteContrato($params);
                }
    
                $nrseqprorrcont = $this->getNumeroProrrogContrato($nrorg);
                $this->salvarProrrogContrato($contrato["NRSEQCONTRATO"], $dtIniRenovacao, $contrato["NRDIASRENOVACAO"], $nrorg, $cdoperador, false, $nrseqprorrcont, $dtAntInicialContrato, $dtAntFinalContrato);
                
                /*Regera as parcelas de Faturamento do contrato*/
                $procedure = new FctGerarParcelasFatura($this->connection);
                $procedure->executar($contrato["NRSEQCONTRATO"], $nrorg, $cdoperador, 1);
                
                $this->validarDuplicidadeFaturamento($contrato["NRSEQCONTRATO"], $dtIniRenovacao, $nrorg, $cdoperador);
                
                /*Refaz a integração com o OM*/    
                $this->reajusteService->refazerIntegracaoOM($contrato["NRSEQCONTRATO"], $nrorg);
                
            }  
            
            $this->connection->commit();
        
        } catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }
    
     /**
     * Recebe os dados de Indice Financeiro
    **/
    public function getDadosIndFinanc($nrseqcontrato, $nrorg) {
    
        $params = array(
            "NRSEQCONTRATO"   => '_'.$nrseqcontrato.'_',
            "NRORG"           => $nrorg
        );
        
        $dados = $this->renovacaofactory->getDadosIndFinanc($params);
        
        return $dados;
    }
    
    //#region REAJUSTE AUTOMÁTICO

    /**
     * Procedimento responsável por apagar todos os registros da tabela de Log de uma organização.
     *
     * @param [string] $nrorg - Organização em questão
     * @return void
     */
    public function deletarLogErroReajuste($nrorg)
    {
        try {
            $this->reajusteService->deletarLogErroReajuste($nrorg);
        } catch (\Exception $e) {
            echo "ORGANIZAÇÃO: " . $nrorg . " | ERRO ao deletar logs de contratos de reajuste automaticamente: " . $e->getMessage();
        }
    }


    /**
     * Procedimento responsável por reajustar contratos automaticamente de uma organização.
     *
     * @param [string] $nrorg - Organização em questão
     */
    public function reajustarContratosAutomaticamente($nrorg)
    {
        try {
            return $this->reajusteService->reajustarContratosAutomaticamente($nrorg);
        } catch (\Exception $e) {
            echo "ORGANIZAÇÃO: " . $nrorg . " | ERRO ao reajustar contratos automaticamente: " . $e->getMessage();
        }
    }
    //#endregion

    /**
     * Rotina criada para anular a parcela gerada de medição de faturamento pendente no mês da renovação.
     */
    public function validarDuplicidadeFaturamento($nrSeqContrato, $dataIniVigencia, $nrorg, $cdoperador) {

        $params = array(
            "NRSEQCONTRATO"   => $nrSeqContrato,
            "NRORG"           => $nrorg
        );

        $dadosEscopo = $this->renovacaofactory->verificaDadosEscopoContr($params);
        
        if (count($dadosEscopo) > 0) {

            if (($dadosEscopo[0]["IDTPFATURA"] == 'X') && ($dadosEscopo[0]["IDTPCALCPARCINC"] == 2)) {

                /* Cancelar a medição duplicada*/

                $paramsMed = array(
                    "NRSEQCONTRATO"   => $nrSeqContrato,
                    "MESRENOVACAO"    => $dataIniVigencia,
                    "NRORG"           => $nrorg
                );

                $medicaoDup = $this->renovacaofactory->getMedicoesCancelar($paramsMed);
                
                if (count($medicaoDup) > 1){
                    $cancelado = 'N';
                    foreach($medicaoDup as $ind => $medicao){

                        if ($cancelado === 'N') {
                            if (($medicao['IDSITUACAO'] == '1') || ($medicao['IDSITUACAO'] == '3') || ($medicao['IDSITUACAO'] == '5')) {
                                $paramsMed2 = array(
                                    "NRMEDICAOFATURA"   => $medicao["NRMEDICAOFATURA"],
                                    "NRORG"             => $nrorg
                                );

                                $this->renovacaofactory->cancelaMedicoesDuplicadas($paramsMed2, $ind);

                                $cancelado = 'S'; 
                            } 
                            else{

                                $paramsValParc = array(
                                    "NRSEQCONTRATO"   => $nrSeqContrato,
                                    "NRORG"           => $nrorg,
                                    "NRMEDICAOFATURA"   => $medicao["NRMEDICAOFATURA"],
                                );  

                                $situParc = $this->renovacaofactory->ValidaSituacaoParcelaMedicao($paramsValParc, $ind);

                                if (($situParc == '1') || ($situParc == '5')) {

                                    // Exclui a parcela de apuração gerada através da medição de faturamento.
                                    $procedureCancApu = new FctCancelarApuraMedicao($this->connection);
                                    $procedureCancApu->executar('_'.$medicao["NRMEDICAOFATURA"].'_','_'.$nrSeqContrato.'_', $nrorg, $cdoperador);

                                   // Cancela o cálculo da medição de faturamento
                                    $procedureCancMed = new FctCancelarMedicao($this->connection);
                                    $procedureCancMed->executar('_'.$medicao["NRMEDICAOFATURA"].'_','_'.$nrSeqContrato.'_', $nrorg, $cdoperador);

                                    $paramsMed2 = array(
                                        "NRMEDICAOFATURA"   => $medicao["NRMEDICAOFATURA"],
                                        "NRORG"             => $nrorg
                                    );

                                    $this->renovacaofactory->cancelaMedicoesDuplicadas($paramsMed2, $ind);

                                    $cancelado = 'S'; 
                                }

                            } 
                        }
                    }
                }

                /* Anular parcela duplicada, caso passe da medição */

                $paramsParc = array(
                    "NRSEQCONTRATO"   => $nrSeqContrato,
                    "MESRENOVACAO"    => $dataIniVigencia,
                    "NRORG"           => $nrorg
                );

                $parcDup = $this->renovacaofactory->getParcelasAnular($paramsParc);

                if (count($parcDup) > 1) {
                    $anulado = 'N';
                    foreach($parcDup as $ind => $parc){

                        if ($anulado === 'N') {

                            if (($parc['IDSITUACAO'] == '1') || ($parc['IDSITUACAO'] == '5')) {
                                $paramsParc2 = array(
                                    "NRFATURACONT"   => $parc["NRFATURACONT"],
                                    "NRORG"          => $nrorg
                                );

                                $this->renovacaofactory->anulaParcelasDuplicadas($paramsParc2, $ind);

                                $anulado = 'S';
                            }
                        }
                    }
                }
            }
        }
    }
    
}

?>