<?php

namespace Teknisa\SM\Service;

use Teknisa\SM\Service\ApropriacaoRecursoService;
use Teknisa\SM\Service\Sm00015004DesalocacaoRecursosService;
use Teknisa\Libs\Util\DateUtil;
use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Util\Procedure\FctDesalocaRecursos;
use Teknisa\SM\Factory\Sm00015004EquipeDeTrabalhoFactory;
use Teknisa\Model\Geral\Entities\Parcnegocio;
use Teknisa\Model\Geral\Entities\Enderecoparc;
use Teknisa\Model\Geral\Entities\Comunicaparc;
use Teknisa\Model\Geral\Entities\Contcorrparc;
use Teknisa\Model\Geral\Entities\Parceria;
use Teknisa\Model\Gestaopessoas\Entities\GpePessoa;
use Teknisa\Model\Gestaopessoas\Entities\GpePessoah;
use DateTime;

class Sm00015004EquipeDeTrabalhoService {
    
    protected $apropriacaoRecursoService;
    protected $desalocacaoService;
    protected $equipeFactory;
    protected $connection;
    protected $environment;
    protected $entityManager;
    
    public function __construct(ApropriacaoRecursoService $apropriacaoRecursoService, Sm00015004DesalocacaoRecursosService $desalocacaoService, Sm00015004EquipeDeTrabalhoFactory $equipeFactory, EntityManager $entityManager, Environment $environment, NewCode $newCode) {
        $this->apropriacaoRecursoService = $apropriacaoRecursoService;
        $this->desalocacaoService = $desalocacaoService;
        $this->equipeFactory = $equipeFactory;
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
        $this->environment  = $environment;
        $this->newCode = $newCode;
    }
     
    /**
     * Função que retona o calculo de intervalo
     * Faz consuta  de validação de datas no banco
     * Tratamento do formato da data 
     * Insere ou deleta registro de apropiação de recurso
     */
    public function calculoIntervalo($inserindo, $diasSemana, $dataInicial, $dataFinal, $nrrecursosagendcont, $nrparcnegrecurso, $nrparcinterlocutor, $nrorg, $cdoperador, $nrseqcontrato, $descansoRemunerado) {
        $numeroDiasSemana = array(
            "IDREPETDOMINGO" => 1,
            "IDREPETSEGUNDA" => 2,
            "IDREPETTERCA"   => 3,
            "IDREPETQUARTA"  => 4,
            "IDREPETQUINTA"  => 5,
            "IDREPETSEXTA"   => 6,
            "IDREPETSABADO"  => 7
        );

        foreach ($diasSemana as &$dia) {
            $dia = $numeroDiasSemana[$dia];
        }
        unset($dia);

        $dataInicial = DateUtil::getDataDeString($dataInicial, DateUtil::FORMATO_BRASILEIRO, true);
        $dataFinal   = DateUtil::getDataDeString($dataFinal, DateUtil::FORMATO_BRASILEIRO, true);
        $diferencaDias           = DateUtil::getQtdeDiasEntre($dataInicial, $dataFinal);
        $datasApropriacaoDaTela  = $this->fomatarDatas($diferencaDias, $dataInicial, $diasSemana, $descansoRemunerado);
        $consultaParaAvaliacao   = $this->apropriacaoRecursoService->recuperarParaValidacao($nrparcnegrecurso, $nrorg);
        $datasApropriacaoDoBanco = array();
        foreach ($consultaParaAvaliacao as $linha) {
            $datasApropriacaoDoBanco[] = $linha["DTAPROPRIACAO"];
        }

        $itensParaInserir = array_diff($datasApropriacaoDaTela, $datasApropriacaoDoBanco);
        $itensParaExcluir = array_diff($datasApropriacaoDoBanco, $datasApropriacaoDaTela);
        //var_dump($itensParaExcluir, $datasApropriacaoDoBanco, $datasApropriacaoDaTela); die;

        if (count($itensParaExcluir) > 0) {
            $this->apropriacaoRecursoService->deletarApropriacaoRecurso($nrrecursosagendcont, array_shift($itensParaExcluir), $nrorg, null, implode(",", $diasSemana));
        }
        foreach ($itensParaInserir as $dataFormatada) {
            $idDiaSemana = date_create_from_format("d/m/Y", $dataFormatada)->format("w") + 1;
            $idDiaUtil = $this->verificarDiaUtil($dataFormatada, $nrseqcontrato, $nrorg);
            $this->apropriacaoRecursoService->inserirApropriacaoRecurso($nrrecursosagendcont, $nrparcnegrecurso, $dataFormatada, $nrparcinterlocutor, $nrorg, $cdoperador, $idDiaSemana, $idDiaUtil);
        }
    }
     
    /**
     *  Realiza a formatação de datas para excluir a parte que apresentra horas
     */
    public function fomatarDatas($diferencaDias, $dataApropriacao, $diasSemana, $descansoRemunerado) {
        $datasApropriacaoDaTela = array();
        if ($descansoRemunerado == "N") {
            for ($i = 0; $i <= $diferencaDias; $i++) {
                $diaSemana = $dataApropriacao->format("w") + 1;
                if (in_array($diaSemana, $diasSemana)) {
                    $dataFormatada = $dataApropriacao->format("d/m/Y");
                    $datasApropriacaoDaTela[] = $dataFormatada;
                }
                $dataApropriacao = DateUtil::adicionaIntervalo($dataApropriacao, 1);
            }
        } else {
            for ($i = 0; $i <= $diferencaDias; $i++) {
                $diaSemana = $dataApropriacao->format("w") + 1;
                if (in_array($diaSemana, $diasSemana) || in_array($diaSemana, array(1, 7))) {
                    $dataFormatada = $dataApropriacao->format("d/m/Y");
                    $datasApropriacaoDaTela[] = $dataFormatada;
                }
                
                $dataApropriacao = DateUtil::adicionaIntervalo($dataApropriacao, 1);
            }
        }
        return $datasApropriacaoDaTela;
    }
      
   /**
    * Função que:
    *  pesquisa apropiação com recurso e retona a quantidade 
    *  deleta registro de recurso apropiado
    *  atualisa o campo Situação do agendamento da tabela de Recurso
    *  salva um registro de desaloação de recurso
    */
    public function desalocarRecurso($nrrecursosagendcont, $dtdevagendrecurcon, $nrorg, $cdoperador) {
        $this->connection->beginTransaction();
        try {
            $quantidade = $this->apropriacaoRecursoService->recuperarApropriacaoComApontamento($nrrecursosagendcont, $nrorg,$dtdevagendrecurcon);
            
            if ($quantidade > 0) {
                throw new \Exception("APROPRIACAO_COM_APONTAMENTO");
            } else {
                $this->desalocacaoService->saveDesalocacao($nrrecursosagendcont,$dtdevagendrecurcon, $nrorg,$cdoperador); 
                $this->executarProcedureFctDesalocaRecursos($dtdevagendrecurcon);
            }
            
            $params = array(
                "NRRECURSOSAGENDCONT" => $nrrecursosagendcont,
                "DTESCALAENTRADA"     => $dtdevagendrecurcon,
                "NRORG"               => $nrorg
            );
            
            $this->equipeFactory->desalocaEscalaTrabalho($params);
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
     
   /**
    * Função que atualiza o campo situação do agendamento de recuso na tabela de recurso 
    */
    
    public function atualizarSituacaoDoAgendamneto($nrrecursosagendcont,$situacao,$nrorg){
        
        $params = array(
            "IDSITUARECGEND" => $situacao,
            "NRRECURSOSAGENDCONT" => $nrrecursosagendcont,
            "NRORG" => $nrorg
            
        );
        $this->equipeFactory->AtualizarSituacaoDoAgendamneto($params);
    }
    
    /**
     * A função "executarProcedureFctCopiaFormPreco" executa a procedure
     * "FCT_COPIA_FORM_PRECO".
     */
     
    public function executarProcedureFctDesalocaRecursos($dataDesalocacao) {
        $procedure = new FctDesalocaRecursos($this->connection);
        $operador =  $this->environment->getCdOperador();
        $procedure->executar($operador, $dataDesalocacao);
    }
    
    
    /** 
     * a função "inserirRecursos" insere os recursos e seus respectivos agendamentos.
    */
    public function inserirRecursos($row){
        $nrorg    = $this->environment->getNrOrg();
        $operador = $this->environment->getCdOperador();
        $this->connection->beginTransaction();
        
        try {
            if ($row["IDTPRECURSO"] == "2") {
                $row["CDBEMATIVO"] = $row["CHAVE"];
                $row["CDPRODUTO"] = null;
                $row["NRPARCNEPESSOA"] = null;
            }
            else if ($row["IDTPRECURSO"] == "3") {
                $row["CDBEMATIVO"] = null;
                $row["CDPRODUTO"] = $row["CHAVE"];
                $row["NRPARCNEPESSOA"] = null;
            }
            else if ($row["IDTPRECURSO"] == "1") {
                $row["CDBEMATIVO"] = null;
                $row["CDPRODUTO"] = null;
                $row["NRPARCNEPESSOA"] = $row["CHAVE"];
            }
            else {
                $row["CDBEMATIVO"] = null;
                $row["CDPRODUTO"] = null;
                $row["NRPARCNEPESSOA"] = null;
            }
            $nrseqcontrato = isset($row["NRSEQCONTRATO"]) ? $row["NRSEQCONTRATO"] : $this->getNrContrato($row["NRRECURSOSAGENDCONT"], $nrorg);
            $descansoRemunerado = $row["IDDESCANSOREMU"];
            $params = array(
                "NRRECURSOSAGENDCONT"  => $row["NRRECURSOSAGENDCONT"],
                "NRAGENDRECURSOCONT"   => $row["NRAGENDRECURSOCONT"],
                "NRITEMOCONTRATO"      => $row["NRITEMOCONTRATO"],
                "DTINIAGENDRECURSO"    => $row["DTINIAGENDRECURSO"],
                "DTFIMAGENDRECURSO"    => $row["DTFIMAGENDRECURSO"],
                "IDTPRECURSO"          => $row["IDTPRECURSO"],
                "CDPRODUTO"            => $row["CDPRODUTO"],
                "NRPARCNEPESSOA"       => $row["NRPARCNEPESSOA"],
                "CDEMPRESA"            => $row["CDEMPRESA"],
                "CDBEMATIVO"           => $row["CDBEMATIVO"],
                "NRRECURSOSUPERIOR"    => $row["NRRECURSOSUPERIOR"],
                "IDMOTIVOAGENDAMENTO"  => $row["IDMOTIVOAGENDAMENTO"],
                "IDSITUARECGEND"       => $row["IDSITUARECGEND"],
                "DSATIVIDADESAGEND"    => $row["DSATIVIDADESAGEND"],
                "HRPRIMEIRAENTRADA"    => $row["HRPRIMEIRAENTRADA"],
                "HRPRIMEIRASAIDA"      => $row["HRPRIMEIRASAIDA"],
                "HRSEGUNDAENTRADA"     => $row["HRSEGUNDAENTRADA"],
                "HRSEGUNDASAIDA"       => $row["HRSEGUNDASAIDA"],
                "NRTEMPOTOLERANCIA"    => $row["NRTEMPOTOLERANCIA"],
                "IDREPETDOMINGO"       => isset($row["IDREPETDOMINGO"]) ? $row["IDREPETDOMINGO"] : "N",
                "IDREPETSEGUNDA"       => isset($row["IDREPETSEGUNDA"]) ? $row["IDREPETSEGUNDA"] : "N",
                "IDREPETTERCA"         => isset($row["IDREPETTERCA"]) ? $row["IDREPETTERCA"] : "N",
                "IDREPETQUARTA"        => isset($row["IDREPETQUARTA"]) ? $row["IDREPETQUARTA"] : "N",
                "IDREPETQUINTA"        => isset($row["IDREPETQUINTA"]) ? $row["IDREPETQUINTA"] : "N",
                "IDREPETSEXTA"         => isset($row["IDREPETSEXTA"]) ? $row["IDREPETSEXTA"] : "N",
                "IDREPETSABADO"        => isset($row["IDREPETSABADO"]) ? $row["IDREPETSABADO"] : "N",
                "NRORG"                => $nrorg,
                "OPERADOR"             => $operador,
                "IDHORAEXTRA"          => $row["IDHORAEXTRA"],
                "IDESCALATRAB"         => $row["IDESCALATRAB"],
                "HRJORNADADIARIA"      => $row["HRJORNADADIARIA"],
                "HRDESCANSO"           => $row["HRDESCANSO"],
                "HRINTERVALO"          => $row["HRINTERVALO"],
                "IDDESCANSOREMU"       => $descansoRemunerado,
                "IDALTERACAOEQUIPE"    => isset($row["IDALTERACAOEQUIPE"]) ? $row["IDALTERACAOEQUIPE"] : null,
                "NRRECURSOALTEQUIPE"   => isset($row["NRRECURSOALTEQUIPE"]) ? $row["NRRECURSOALTEQUIPE"] : null,
                "DSJUSTIFICAALTEQUIPE" => isset($row["DSJUSTIFICAALTEQUIPE"]) ? $row["DSJUSTIFICAALTEQUIPE"] : null,
                "DTULTATU"             => isset($row["DTULTATU"]) ? $row["DTULTATU"] : null
            );
            
            $this->equipeFactory-> saveRecurso($params);
            
            $pessoa         = $row["NRPARCNEPESSOA"];
            $nomeDiasSemana = $row["DIASDASEMANA"];
            
            if($pessoa != null) {
                $nrrecursosagendcont = $row["NRRECURSOSAGENDCONT"];
                $inserindo           = $row["__is_new"];
                $dataInicial         = $row["DTINIAGENDRECURSO"];
                $dataFinal           = $row["DTFIMAGENDRECURSO"];
                $nomeDiasSemana      = $row["DIASDASEMANA"];
                $nrparcnegrecurso    = $row["NRPARCNEPESSOA"];
                $nrparcinterlocutor  = null;
                $nrorg               = $this->environment->getNrOrg();
                $cdoperador          = $this->environment->getCdOperador();
                
                $this->calculoIntervalo($inserindo, $nomeDiasSemana, $dataInicial, $dataFinal, $nrrecursosagendcont, $nrparcnegrecurso, $nrparcinterlocutor, $nrorg, $cdoperador, $nrseqcontrato, $descansoRemunerado);
                
                if ($inserindo) {
                    $nragendrecursocont  = $row["NRAGENDRECURSOCONT"];
                    $idmotivoagendamento = $row["IDMOTIVOAGENDAMENTO"];
                    $nritemocontrato     = $row["NRITEMOCONTRATO"];
                    
                    $this->consistirAgendamentosPendentes($nragendrecursocont, $nrseqcontrato, $nritemocontrato, $dataFinal, $idmotivoagendamento, $nrorg);
                }
            }
            
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function verificarDiaUtil($data, $nrseqcontrato, $nrorg) {
        $params = array(
            "DATA"          => $data,
            "NRORG"         => $nrorg,
            "NRSEQCONTRATO" => $nrseqcontrato
        );
        
        $dataset = $this->equipeFactory->verificarDiaUtil($params);
        return (int)$dataset[0]["EXISTE"] ? "N" : "S";
    }
    
    public function consistirAgendamentosPendentes($nragendrecursocont, $nrseqcontrato, $nritemocontrato, $novaDataInicial, $idmotivoagendamento, $nrorg) {
        $motivos = array("1", "4"); //EFETIVO e TREINAMENTO
        if (in_array($idmotivoagendamento, $motivos)) {
            $quantidade = $this->getQuantidadeAgendamentosPendentes($nrseqcontrato, $nritemocontrato, $nrorg);
            
            if ($quantidade !== null) {
                if ($quantidade == 1) {
                    $this->excluirAgendamentoPendente($nrseqcontrato, $nritemocontrato, $nrorg);
                } else {
                    $this->atualizarQuantidadeAgendamentoPendente($nragendrecursocont, $nrseqcontrato, $nritemocontrato, $novaDataInicial, $nrorg);
                }
            }
        }
    }
    
    /*public function getDatasDoPeriodo($dataInicial, $dataFinal) {
        $datas = array();
        
        $dataInicial = DateUtil::getDataDeString($dataInicial, DateUtil::FORMATO_BRASILEIRO, true);
        $dataFinal = DateUtil::getDataDeString($dataFinal, DateUtil::FORMATO_BRASILEIRO, true);
        
        $diferencaDias = DateUtil::getQtdeDiasEntre($dataInicial, $dataFinal);
        
        $dataLoop = $dataInicial;
        for ($i = 0; $i <= $diferencaDias; $i++) {
            $datas[] = $dataLoop->format("d/m/Y");
            $dataLoop = DateUtil::adicionaIntervalo($dataLoop, 1);
        }
        
        return $datas;
    }*/
    
    public function getQuantidadeAgendamentosPendentes($nrseqcontrato, $nritemocontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO"      => $nrseqcontrato,
            "NRITEMOCONTRATO"    => $nritemocontrato,
            "NRORG"              => $nrorg
        );
        
        $dataset = $this->equipeFactory->getQuantidadeAgendamentosPendentes($params);
        return (count($dataset) > 0) ? (int)$dataset[0]["QTPENDENCIA"] : null;
    }
    
    public function excluirAgendamentoPendente($nrseqcontrato, $nritemocontrato, $nrorg) {
        $params = array(
            "NRSEQCONTRATO"      => $nrseqcontrato,
            "NRITEMOCONTRATO"    => $nritemocontrato,
            "NRORG"              => $nrorg
        );
        
        $this->equipeFactory->excluirAgendamentoPendente($params);
    }
    
    public function atualizarQuantidadeAgendamentoPendente($nragendrecursocont, $nrseqcontrato, $nritemocontrato, $dtiniagendamento, $nrorg) {
        $params = array(
            "NRAGENDRECURSOCONT" => $nragendrecursocont,
            "DTINIAGENDAMENTO"   => $dtiniagendamento,
            "NRSEQCONTRATO"      => $nrseqcontrato,
            "NRITEMOCONTRATO"    => $nritemocontrato,
            "NRORG"              => $nrorg
        );
        
        $this->equipeFactory->atualizarQuantidadeAgendamentoPendente($params);
    }
    
    public function saveParceiro($row) {
        
        $nrorg = $this->environment->getNrOrg();
        $operador = $this->environment->getCdOperador();
        $currentTime = $this->environment->getCurrentTime();
    
        $parcnegocioRepository = $this->entityManager->getRepository(Parcnegocio::class);
        
        $this->entityManager->beginTransaction();
        try {
           
            $parcnegocio = new Parcnegocio();
            $parcnegocio->setNrorg($nrorg);
            $parcnegocio->setNrparcnegocio($this->newCode->getCodeByTableName('PARCNEGOCIO', $nrorg, 1, 10, true));
            $parcnegocio->setDtinclusao($currentTime);
            $parcnegocio->setCdoperinclusao($operador);
            $parcnegocio->setNrorginclusao($nrorg);
            $parcnegocio->setIdativo("S");
            $parcnegocio->setIdparcfundido('N');
            $nrparcnegocio = $row["NRPARCNEGOCIO"] = $parcnegocio->getNrparcnegocio();
            $parcnegocio->setNrinscricaoparc($row["parcnegocio"]["NRINSCRICAOPARC"]);
            $parcnegocio->setCdtipoinscricao("CPF");
            $parcnegocio->setIdpessoafisica("S");
            $parcnegocio->setNmprincipalparc($row["parcnegocio"]["NMPRINCIPALPARC"]);
            $parcnegocio->setNmsecundariparc($row["parcnegocio"]["NMSECUNDARIPARC"]);
            $parcnegocio->setCdtipoparcprincipal("PESSOA");
            $dtnascifundparc = null;
            
            if (!empty($row["parcnegocio"]["DTNASCIFUNDPARC"])) {
                $data =str_replace("-","/",$row["parcnegocio"]["DTNASCIFUNDPARC"]);
                $dtnascifundparc = DateUtil::getDataDeString($data, DateUtil::FORMATO_AMERICANO_DATAHORA, true);
            }
            
            $parcnegocio->setDtnascifundparc($dtnascifundparc);
            $this->entityManager->persist($parcnegocio);
            $this->entityManager->flush();
            
            if(isset($row["enderecoparc"]) && count($row["enderecoparc"]) > 0)
                $this->salvaEnderecoParceiro($row);
                
            if(isset($row["comunicaparc"]) && count($row["comunicaparc"]) > 0)
                $this->saveContato($row);
                
            $row = $this->savePessoa($row);
            $this->savePessoah($row);
            
            if(!isset($row["contcorrparc"]) && count($row["contcorrparc"]) > 0)
                $this->saveContaParc($row);
            
            $this->saveParceria($row);
            $this->entityManager->commit();
        }
        catch(\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
     public function salvaEnderecoParceiro($row) {

        $nrorg = $this->environment->getNrorgTrab();
        $operador = $this->environment->getCdOperador();
        $currentTime = $this->environment->getCurrentTime();

        $nrparcnegocio = $row["NRPARCNEGOCIO"];

        foreach ($row["enderecoparc"] as $endereco) {

        $this->entityManager->beginTransaction();
       
            try {
                $enderecoparc = new Enderecoparc();
                $enderecoparc->setNrorg($nrorg);
                $enderecoparc->setNrenderecoparc($this->newCode->getCodeByTableName('ENDERECOPARC', $nrorg, 1, 10, true));
                $enderecoparc->setNrparcnegocio($nrparcnegocio);
                $enderecoparc->setDtinclusao($currentTime);
                $enderecoparc->setCdoperinclusao($operador);
                $enderecoparc->setNrorginclusao($nrorg);
                $enderecoparc->setIdativo("S");
                $enderecoparc->setCdtipoendereco($endereco["CDTIPOENDERECO"]);
                $enderecoparc->setCdpais($endereco["CDPAIS"]);
                $enderecoparc->setSgestado($endereco["SGESTADO"]);
                $enderecoparc->setCdmunicipio($endereco["CDMUNICIPIO"]);
                $enderecoparc->setDsendereco($endereco["DSENDERECO"]);
                $enderecoparc->setCdbairro(!empty($endereco["CDBAIRRO"]) ? $endereco["CDBAIRRO"] : null);
                $enderecoparc->setCdlogradouro(!empty($endereco["CDLOGRADOURO"]) ? $endereco["CDLOGRADOURO"] : null);
                $enderecoparc->setNrimovelendereco(!empty($endereco["NRIMOVELENDERECO"]) ? $endereco["NRIMOVELENDERECO"] : null);
                $enderecoparc->setNmbairroendereco(!empty($endereco["NMBAIRROENDERECO"]) ? $endereco["NMBAIRROENDERECO"] : null);
                $enderecoparc->setDscompleendereco(!empty($endereco["DSCOMPLEENDERECO"]) ? $endereco["DSCOMPLEENDERECO"] : null);
                $enderecoparc->setNrcependereco(!empty($endereco["NRCEPENDERECO"]) ? $endereco["NRCEPENDERECO"] : null);
                $enderecoparc->setDsreferenciaende(!empty($endereco["DSREFERENCIAENDE"]) ? $endereco["DSREFERENCIAENDE"] : null);
                $this->entityManager->persist($enderecoparc);
                $this->entityManager->flush();
    
                $this->entityManager->commit();
            } catch(\Exception $e) {
                $this->entityManager->rollback();
                throw $e;
            }
        }
    }
    
    public function saveContato($row) {

        $nrorg = $this->environment->getNrorgTrab();
        $operador = $this->environment->getCdOperador();
        $currentTime = $this->environment->getCurrentTime();

        foreach($row["comunicaparc"] as $comu){
        
            $this->entityManager->beginTransaction();
        
            try{    
                    $comunica = new Comunicaparc();
                    $comunica->setNrparcnegocio($row["NRPARCNEGOCIO"]);
                    $comunica->setNrorg($nrorg);
                    $comunica->setNrcomunicaparc($this->newCode->getCodeByTableName('COMUNICAPARC', $nrorg, 1, 6));
                    $comunica->setDtinclusao($currentTime);
                    $comunica->setCdoperinclusao($operador);
                    $comunica->setNrorginclusao($nrorg);
                    $comunica->setCdformacomu($comu['CDFORMACOMU']);
                    $comunica->setCdcomunicaparc($comu['CDCOMUNICAPARC']);
                    $comunica->setCdprefixcomuparc($comu['CDPREFIXCOMUPARC']);
                    $comunica->setCdcomplecomuparc($comu['CDCOMPLECOMUPARC']);
                    $comunica->setIdativo($comu['IDATIVO']);
                    $this->entityManager->persist($comunica);
                    $this->entityManager->flush();
                    $this->entityManager->commit();
                    
            } catch(\Exception $e) {
                $this->entityManager->rollback();
                throw $e;
            }
        }
    }
    
    public function savePessoa($row) {

        $nrorg = $this->environment->getNrorgTrab();
        $operador = $this->environment->getCdOperador();
        $currentTime = $this->environment->getCurrentTime();
        
        $this->entityManager->beginTransaction();
    
        try{    
            $pessoa = new GpePessoa();
            $pessoa->setNrpessoa($this->newCode->getCodeByTableName('GPEPESSOA', $nrorg, 1, 10, true));
            $pessoa->setCdoperinclusao($operador);
            $pessoa->setCdoperultatu($operador);
            $pessoa->setDtinclusao($currentTime);
            $pessoa->setDtultatu($currentTime);
            $pessoa->setNrorg($nrorg);
            $pessoa->setNrorginclusao($nrorg);
            $pessoa->setNrorgultatu($nrorg);
            $pessoa->setNrparcnegocio($row["NRPARCNEGOCIO"]);
            $row["NRPESSOA"] = $pessoa->getNrpessoa();
            
            $this->entityManager->persist($pessoa);
            $this->entityManager->flush();
            $this->entityManager->commit();
            return $row;
                
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    
    }
    
    public function savePessoah($row) {

        $nrorg = $this->environment->getNrorgTrab();
        $operador = $this->environment->getCdOperador();
        $currentTime = $this->environment->getCurrentTime();
        
        $this->entityManager->beginTransaction();
    
        try{    
            $pessoah = new GpePessoah();
            $pessoah->setNrpessoah($this->newCode->getCodeByTableName('GPEPESSOAH', $nrorg, 1, 10, true));
            $pessoah->setNrorg($nrorg);
            $pessoah->setNrorginclusao($nrorg);
            $pessoah->setNrorgultatu($nrorg);
            $pessoah->setDtinclusao($currentTime);
            $pessoah->setDtultatu($currentTime);
            $pessoah->setCdoperinclusao($operador);
            $pessoah->setCdoperultatu($operador);
            $pessoah->setNrpessoa($row["NRPESSOA"]);
            
            $pessoah->setCdestacivil(!empty($row["gpe_pessoah"]["CDESTACIVIL"]) ? $row["gpe_pessoah"]["CDESTACIVIL"] : null);
            $pessoah->setCdexcertresepes(!empty($row["gpe_pessoah"]["CDEXCERTRESEPES"]) ? $row["gpe_pessoah"]["CDEXCERTRESEPES"] : null);
            $pessoah->setCdexrgpessoa(!empty($row["gpe_pessoah"]["CDEXRGPESSOA"]) ? $row["gpe_pessoah"]["CDEXRGPESSOA"] : null);
            $pessoah->setCdmunicipio(!empty($row["gpe_pessoah"]["CDMUNICIPIO"]) ? $row["gpe_pessoah"]["CDMUNICIPIO"] : null);
            $pessoah->setCdpais(!empty($row["gpe_pessoah"]["CDPAIS"]) ? $row["gpe_pessoah"]["CDPAIS"] : null);
            $pessoah->setCdtpbaixapag(!empty($row["gpe_pessoah"]["CDTPBAIXAPAG"]) ? $row["gpe_pessoah"]["CDTPBAIXAPAG"] : null);
            $pessoah->setDsapelidopess(!empty($row["gpe_pessoah"]["DSAPELIDOPESS"]) ? $row["gpe_pessoah"]["DSAPELIDOPESS"] : null);
            $pessoah->setDscaminhofoto(!empty($row["gpe_pessoah"]["DSCAMINHOFOTO"]) ? $row["gpe_pessoah"]["DSCAMINHOFOTO"] : null);
            $pessoah->setDscategcertrese(!empty($row["gpe_pessoah"]["DSCATEGCERTRESE"]) ? $row["gpe_pessoah"]["DSCATEGCERTRESE"] : null);
            $pessoah->setDscateghabcart(!empty($row["gpe_pessoah"]["DSCATEGHABCART"]) ? $row["gpe_pessoah"]["DSCATEGHABCART"] : null);
            $pessoah->setDscomplcertnasc(!empty($row["gpe_pessoah"]["DSCOMPLCERTNASC"]) ? $row["gpe_pessoah"]["DSCOMPLCERTNASC"] : null);
            $pessoah->setDslocalexrgpes(!empty($row["gpe_pessoah"]["DSLOCALEXRGPES"]) ? $row["gpe_pessoah"]["DSLOCALEXRGPES"] : null);
            $pessoah->setDsnomemeiopess(!empty($row["gpe_pessoah"]["DSNOMEMEIOPESS"]) ? $row["gpe_pessoah"]["DSNOMEMEIOPESS"] : null);
            $pessoah->setDsprinomepess(!empty($row["gpe_pessoah"]["DSPRINOMEPESS"]) ? $row["gpe_pessoah"]["DSPRINOMEPESS"] : null);
            $pessoah->setDspronometrat(!empty($row["gpe_pessoah"]["DSPRONOMETRAT"]) ? $row["gpe_pessoah"]["DSPRONOMETRAT"] : null);
            $pessoah->setDsultnomepess(!empty($row["gpe_pessoah"]["DSULTNOMEPESS"]) ? $row["gpe_pessoah"]["DSULTNOMEPESS"] : null);
            $pessoah->setDtcasapessoa(!empty($row["gpe_pessoah"]["DTCASAPESSOA"]) ? $this->retornaData($row["gpe_pessoah"]["DTCASAPESSOA"]) : null);
            $pessoah->setDtcertresepes(!empty($row["gpe_pessoah"]["DTCERTRESEPES"]) ? $this->retornaData($row["gpe_pessoah"]["DTCERTRESEPES"]) : null);
            $pessoah->setDtchegadapais(!empty($row["gpe_pessoah"]["DTCHEGADAPAIS"]) ? $this->retornaData($row["gpe_pessoah"]["DTCHEGADAPAIS"]) : null);
            $pessoah->setDtctpspessoa(!empty($row["gpe_pessoah"]["DTCTPSPESSOA"]) ? $this->retornaData($row["gpe_pessoah"]["DTCTPSPESSOA"]) : null);
            $pessoah->setDtexconsreg(!empty($row["gpe_pessoah"]["DTEXCONSREG"]) ? $this->retornaData($row["gpe_pessoah"]["DTEXCONSREG"]) : null);
            $pessoah->setDtexrgpessoa(!empty($row["gpe_pessoah"]["DTEXRGPESSOA"]) ? $this->retornaData($row["gpe_pessoah"]["DTEXRGPESSOA"]) : null);
            $pessoah->setDtfimvigencia(!empty($row["gpe_pessoah"]["DTFIMVIGENCIA"]) ? $this->retornaData($row["gpe_pessoah"]["DTFIMVIGENCIA"]) : null);
            $pessoah->setDthabcartpes(!empty($row["gpe_pessoah"]["DTHABCARTPES"]) ? $this->retornaData($row["gpe_pessoah"]["DTHABCARTPES"]) : null);
            $pessoah->setDtinivigencia(!empty($row["gpe_pessoah"]["DTINIVIGENCIA"]) ? $this->retornaData($row["gpe_pessoah"]["DTINIVIGENCIA"]) : null);
            $pessoah->setDtinscpispasep(!empty($row["gpe_pessoah"]["DTINSCPISPASEP"]) ? $this->retornaData($row["gpe_pessoah"]["DTINSCPISPASEP"]) : null);
            $pessoah->setDtmescompetenc(!empty($row["gpe_pessoah"]["DTMESCOMPETENC"]) ? $this->retornaData($row["gpe_pessoah"]["DTMESCOMPETENC"]) : null);
            $pessoah->setDtnascpessoa(!empty($row["gpe_pessoah"]["DTNASCPESSOA"]) ? $this->retornaData($row["gpe_pessoah"]["DTNASCPESSOA"]) : null);
            $pessoah->setDtnaturalizapes(!empty($row["gpe_pessoah"]["DTNATURALIZAPES"]) ? $this->retornaData($row["gpe_pessoah"]["DTNATURALIZAPES"]) : null);
            $pessoah->setDtpermavisto(!empty($row["gpe_pessoah"]["DTPERMAVISTO"]) ? $this->retornaData($row["gpe_pessoah"]["DTPERMAVISTO"]) : null);
            $pessoah->setDtvalhabcartpes(!empty($row["gpe_pessoah"]["DTVALHABCARTPES"]) ? $this->retornaData($row["gpe_pessoah"]["DTVALHABCARTPES"]) : null);
            $pessoah->setIdfatorrhpes(!empty($row["gpe_pessoah"]["IDFATORRHPES"]) ? $row["gpe_pessoah"]["IDFATORRHPES"] : null);
            $pessoah->setIdgrupsangupes(!empty($row["gpe_pessoah"]["IDGRUPSANGUPES"]) ? $row["gpe_pessoah"]["IDGRUPSANGUPES"] : null);
            $pessoah->setIdisentituelei(!empty($row["gpe_pessoah"]["IDISENTITUELEI"]) ? $row["gpe_pessoah"]["IDISENTITUELEI"] : null);
            $pessoah->setIdpesnaturaliza(!empty($row["gpe_pessoah"]["IDPESNATURALIZA"]) ? $row["gpe_pessoah"]["IDPESNATURALIZA"] : null);
            $pessoah->setIdpossuifilho(!empty($row["gpe_pessoah"]["IDPOSSUIFILHO"]) ? $row["gpe_pessoah"]["IDPOSSUIFILHO"] : null);
            $pessoah->setIdposvistoperm(!empty($row["gpe_pessoah"]["IDPOSVISTOPERM"]) ? $row["gpe_pessoah"]["IDPOSVISTOPERM"] : null);
            $pessoah->setIdsexopessoa(!empty($row["gpe_pessoah"]["IDSEXOPESSOA"]) ? $row["gpe_pessoah"]["IDSEXOPESSOA"] : null);
            $pessoah->setNmpessoa(!empty($row["gpe_pessoah"]["NMPESSOA"]) ? $row["gpe_pessoah"]["NMPESSOA"] : null);
            $pessoah->setNranochegapais(!empty($row["gpe_pessoah"]["NRANOCHEGAPAIS"]) ? $row["gpe_pessoah"]["NRANOCHEGAPAIS"] : null);
            $pessoah->setNrcarthabpes(!empty($row["gpe_pessoah"]["NRCARTHABPES"]) ? $row["gpe_pessoah"]["NRCARTHABPES"] : null);
            $pessoah->setNrcatmilitarpe(!empty($row["gpe_pessoah"]["NRCATMILITARPE"]) ? $row["gpe_pessoah"]["NRCATMILITARPE"] : null);
            $pessoah->setNrcertcasapes(!empty($row["gpe_pessoah"]["NRCERTCASAPES"]) ? $row["gpe_pessoah"]["NRCERTCASAPES"] : null);
            $pessoah->setNrcertnascpes(!empty($row["gpe_pessoah"]["NRCERTNASCPES"]) ? $row["gpe_pessoah"]["NRCERTNASCPES"] : null);
            $pessoah->setNrcertobito(!empty($row["gpe_pessoah"]["NRCERTOBITO"]) ? $row["gpe_pessoah"]["NRCERTOBITO"] : null);
            $pessoah->setNrcertresepes(!empty($row["gpe_pessoah"]["NRCERTRESEPES"]) ? $row["gpe_pessoah"]["NRCERTRESEPES"] : null);
            $pessoah->setNrcondfispes(!empty($row["gpe_pessoah"]["NRCONDFISPES"]) ? $row["gpe_pessoah"]["NRCONDFISPES"] : null);
            $pessoah->setNrconselhoreg(!empty($row["gpe_pessoah"]["NRCONSELHOREG"]) ? $row["gpe_pessoah"]["NRCONSELHOREG"] : null);
            $pessoah->setNrcpfpessoa(!empty($row["gpe_pessoah"]["NRCPFPESSOA"]) ? $row["gpe_pessoah"]["NRCPFPESSOA"] : null);
            $pessoah->setNrctpspessoa(!empty($row["gpe_pessoah"]["NRCTPSPESSOA"]) ? $row["gpe_pessoah"]["NRCTPSPESSOA"] : null);
            $pessoah->setNrdocuestrang(!empty($row["gpe_pessoah"]["NRDOCUESTRANG"]) ? $row["gpe_pessoah"]["NRDOCUESTRANG"] : null);
            $pessoah->setNrfolhacertcasa(!empty($row["gpe_pessoah"]["NRFOLHACERTCASA"]) ? $row["gpe_pessoah"]["NRFOLHACERTCASA"] : null);
            $pessoah->setNrfolhacertnasc(!empty($row["gpe_pessoah"]["NRFOLHACERTNASC"]) ? $row["gpe_pessoah"]["NRFOLHACERTNASC"] : null);
            $pessoah->setNrgrauinstr(!empty($row["gpe_pessoah"]["NRGRAUINSTR"]) ? $row["gpe_pessoah"]["NRGRAUINSTR"] : null);
            $pessoah->setNridadefilho(!empty($row["gpe_pessoah"]["NRIDADEFILHO"]) ? $row["gpe_pessoah"]["NRIDADEFILHO"] : null);
            $pessoah->setNrinscinsspes(!empty($row["gpe_pessoah"]["NRINSCINSSPES"]) ? $row["gpe_pessoah"]["NRINSCINSSPES"] : null);
            $pessoah->setNrinscisspes(!empty($row["gpe_pessoah"]["NRINSCISSPES"]) ? $row["gpe_pessoah"]["NRINSCISSPES"] : null);
            $pessoah->setNrinscrconsreg(!empty($row["gpe_pessoah"]["NRINSCRCONSREG"]) ? $row["gpe_pessoah"]["NRINSCRCONSREG"] : null);
            $pessoah->setNrlivrocertcasa(!empty($row["gpe_pessoah"]["NRLIVROCERTCASA"]) ? $row["gpe_pessoah"]["NRLIVROCERTCASA"] : null);
            $pessoah->setNrlivrocertnasc(!empty($row["gpe_pessoah"]["NRLIVROCERTNASC"]) ? $row["gpe_pessoah"]["NRLIVROCERTNASC"] : null);
            $pessoah->setNrnacionalid(!empty($row["gpe_pessoah"]["NRNACIONALID"]) ? $row["gpe_pessoah"]["NRNACIONALID"] : null);
            $pessoah->setNrpispaseppes(!empty($row["gpe_pessoah"]["NRPISPASEPPES"]) ? $row["gpe_pessoah"]["NRPISPASEPPES"] : null);
            $pessoah->setNrracapessoa(!empty($row["gpe_pessoah"]["NRRACAPESSOA"]) ? $row["gpe_pessoah"]["NRRACAPESSOA"] : null);
            $pessoah->setNrregctpspes(!empty($row["gpe_pessoah"]["NRREGCTPSPES"]) ? $row["gpe_pessoah"]["NRREGCTPSPES"] : null);
            $pessoah->setNrrgpessoa(!empty($row["gpe_pessoah"]["NRRGPESSOA"]) ? $row["gpe_pessoah"]["NRRGPESSOA"] : null);
            $pessoah->setNrsecaeleipes(!empty($row["gpe_pessoah"]["NRSECAELEIPES"]) ? $row["gpe_pessoah"]["NRSECAELEIPES"] : null);
            $pessoah->setNrseriectpspes(!empty($row["gpe_pessoah"]["NRSERIECTPSPES"]) ? $row["gpe_pessoah"]["NRSERIECTPSPES"] : null);
            $pessoah->setNrtitueleipes(!empty($row["gpe_pessoah"]["NRTITUELEIPES"]) ? $row["gpe_pessoah"]["NRTITUELEIPES"] : null);
            $pessoah->setNrzonaeleipes(!empty($row["gpe_pessoah"]["NRZONAELEIPES"]) ? $row["gpe_pessoah"]["NRZONAELEIPES"] : null);
            $pessoah->setSgestado(!empty($row["gpe_pessoah"]["SGESTADO"]) ? $row["gpe_pessoah"]["SGESTADO"] : null);
            $pessoah->setSgufconsreg(!empty($row["gpe_pessoah"]["SGUFCONSREG"]) ? $row["gpe_pessoah"]["SGUFCONSREG"] : null);
            $pessoah->setSgufctpspes(!empty($row["gpe_pessoah"]["SGUFCTPSPES"]) ? $row["gpe_pessoah"]["SGUFCTPSPES"] : null);
            
            $this->entityManager->persist($pessoah);
            $this->entityManager->flush();
            $this->entityManager->commit();
                
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    
    }
    
    public function saveContaParc($row) {

        $nrorg = $this->environment->getNrorgTrab();
        $operador = $this->environment->getCdOperador();
        $currentTime = $this->environment->getCurrentTime();
        
        $this->entityManager->beginTransaction();
    
        try{    
            $conta = new Contcorrparc();
            $conta->setCdagencia($row["contcorrparc"]["CDAGENCIA"]);
            $conta->setCdbanco($row["contcorrparc"]["CDBANCO"]);
            $conta->setCdcontcorr($row["contcorrparc"]["CDCONTCORR"]);
            $conta->setCdoperinclusao($operador);
            $conta->setCdoperultatu($operador);
            $conta->setCdreducont($row["contcorrparc"]["CDREDUCONT"]);
            $conta->setDtinclusao($currentTime);
            $conta->setDtultatu($currentTime);
            $conta->setIdativo($row["contcorrparc"]["IDATIVO"]);
            $conta->setNrcontcorrparc($this->newCode->getCodeByTableName('CONTCORRPARC', $nrorg, 1, 10, true));
            $conta->setNrorg($nrorg);
            $conta->setNrorginclusao($nrorg);
            $conta->setNrorgultatu($nrorg);
            $conta->setNrparcnegocio($row["contcorrparc"]["NRPARCNEGOCIO"]);
            $conta->setNrtpcontcorr($row["contcorrparc"]["NRTPCONTCORR"]);
            
            
            $this->entityManager->persist($conta);
            $this->entityManager->flush();
            $this->entityManager->commit();
                
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    
    }
    
    public function saveParceria($row) {
        $nrorg       = $this->environment->getNrorgTrab();
        $operador    = $this->environment->getCdOperador();
        $currentTime = $this->environment->getCurrentTime();
        
        $this->entityManager->beginTransaction();
    
        try{    
            $parceria = new Parceria();
            $parceria->setCdoperinclusao($operador);
            $parceria->setCdoperultatu($operador);
            $parceria->setDtinclusao($currentTime);
            $parceria->setDtultatu($currentTime);
            $parceria->setNrorginclusao($nrorg);
            $parceria->setNrorgultatu($nrorg);
            $parceria->setNrorg($nrorg);
            $parceria->setIdativo("S");
            $parceria->setCdtipoparceiro("PESSOA");
            $parceria->setNrparceria($this->newCode->getCodeByTableName('PARCERIA', $nrorg, 1, 10, true));
            $parceria->setNrparcnegocio($row["NRPARCNEGOCIO"]);
            
            $this->entityManager->persist($parceria);
            $this->entityManager->flush();
            $this->entityManager->commit();
                
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    
    }
    
    public function getUrlIntegracaoHcm($nrorg){
        $param = array(
            "NRORG" => $nrorg
        );
        
        $dataset = $this->equipeFactory->getUrlIntegracaoHcm($param);
        return $dataset[0]["URLINTEGRACAOHCM"];
    }
    
    public function retornaData($stringData){
        $data =str_replace("-","/",$stringData);
        $date = DateUtil::getDataDeString($data, DateUtil::FORMATO_AMERICANO_DATAHORA, true);
        return $date;
    }
    
    /**
     * Busca os dados da escala de trabalho e do recurso a ser substituido ou coberto 
     * e salva no novo recurso alocado
    **/
    public function geraEscalaSubstituicao($nrrecursoatual, $nrrecursonovo, $dtiniagendamento, $dtfimagendamento, $nrorg, $diasdasemana = null){
        try{
            $params = array(
                "NRRECURSOSAGENDCONT" => $nrrecursoatual,
                "DTESCALAENTRADA"     => $dtiniagendamento,
                "DTESCALASAIDA"       => $dtfimagendamento,
                "NRORG"               => $nrorg
            );
            $results = $this->equipeFactory->getEscalaTrabalho($params);
            if(count($results) > 0){
                foreach ($results as &$result) {
                    $result["NRRECURSOSAGENDCONT"] = $nrrecursonovo;
                }
                
                unset($result);
                $this->saveEscalaTrabalho($results, $nrorg, $this->environment->getCdOperador(), $nrrecursoatual, $diasdasemana);
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Salva uma equipe de trabalho inserida manualmente pelo usuário
     * num recurso da equipe de trabalho
    **/
    public function saveEscalaTrabalho($rows, $nrorg, $cdoperador, $nrrecursoatual = null, $diasdasemana = null){
        try {

            $this->entityManager->beginTransaction();
            $diasNAlocados = array();
            foreach($rows as $row){
                if(!is_array($row["NRRECURSOSAGENDCONT"]))
                    $nrrecursosagendcont = array($row["NRRECURSOSAGENDCONT"]);
                else 
                    $nrrecursosagendcont = $row["NRRECURSOSAGENDCONT"];
                if(!is_array($row["NRPARCNEPESSOA"]))
                    $nrparcnegrecurso = array($row["NRPARCNEPESSOA"]);
                else
                $nrparcnegrecurso = array($row["NRPARCNEPESSOA"]);

                foreach($nrrecursosagendcont as $nrrecurso){
                    $nrparcinterlocutor  = null;
                    $diasSemana          = isset($diasdasemana) ? $diasdasemana : null ;
                    $nrseqcontrato       = isset($row["NRSEQCONTRATO"]) ? $row["NRSEQCONTRATO"] : $this->getNrContrato($nrrecursoatual, $nrorg);
                    $descansoRemunerado  = $row["IDDESCANSOREMU"];
                    $dataInicial         = $row["DTINIAGENDRECURSO"];
                    $dataFinal           = $row["DTFIMAGENDRECURSO"];
                    $nrescalaagend = $this->newCode->getCodeByTableName('NRESCALARECURSOSAGENDCONT', $nrorg, 1, 10, true);
                    $params = array(
                        "NRRECURSOSAGENDCONT"      => $nrrecurso,
                        "NRESCALARECURSOSAGENDCONT"=> $nrescalaagend,
                        "DTESCALAENTRADA"          => $row["DTESCALAENTRADA"],
                        "DTESCALASAIDA"            => $row["DTESCALASAIDA"],
                        "HRINICIAL"                => $row["HRINICIAL"],
                        "HRFINAL"                  => $row["HRFINAL"],
                        "HRINTERVALO"              => $row["HRINTERVALO"],
                        "NRORG"                    => $nrorg,
                        "NRORGINCLUSAO"            => $nrorg,
                        "CDOPERINCLUSAO"           => $cdoperador
                    );
                    $this->equipeFactory->saveEscalaTrabalho($params);
                    if(!empty($row["NRPARCNEPESSOA"])){
                        foreach($nrparcnegrecurso as $nrparc)
                        $this->calculoIntervalo(true, $diasSemana, $dataInicial, $dataFinal, $nrrecurso, $nrparc, $nrparcinterlocutor, $nrorg, $cdoperador, $nrseqcontrato, $descansoRemunerado);
                    }
                        $this->salvarApropiacaoEdicaoEscala($row, $nrorg, $cdoperador, $dataInicial, $dataFinal);
                    }
                }
            $this->entityManager->commit();
        } catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    /**
     * Valida na tabela de apropriação os
     * dias editados como folga na escala de trabalo
     **/
    public function salvarApropiacaoEdicaoEscala($row, $nrorg, $cdoperador, $dtiniagendamento, $dtfimagendamento){
        if(is_array($row["NRRECURSOSAGENDCONT"]))
            $nrrecursos = $row["NRRECURSOSAGENDCONT"];
        else 
            $nrrecursos = array($row["NRRECURSOSAGENDCONT"]);
        if(is_array($row["DIASDASEMANA"]))
            $diasSemana = $row["DIASDASEMANA"];
        else 
            $diasSemana = array($row["DIASDASEMANA"]);

        foreach ($nrrecursos as $nrrecurso) {
            $datasEscala = $this->getDiasNaotrabalhadosEscala($nrrecurso, $dtiniagendamento, $dtfimagendamento, $nrorg);
            foreach ($datasEscala as $dataEscala) {
                $idDiaSemana = date_create_from_format("d/m/Y H:i:s", $dataEscala["DTESCALAENTRADA"])->format("w") + 1;
                if($row["IDDESCANSOREMU"] == "N" || ($row["IDDESCANSOREMU"] == "S" && !(in_array($idDiaSemana, $diasSemana) || in_array($idDiaSemana, array(1, 7)))))
                    $this->apropriacaoRecursoService->deletarApropriacaoRecurso($nrrecurso, $dataEscala["DTESCALAENTRADA"], $nrorg, "EDIT", implode(",", $diasSemana));
            }
        }
    }

    /**
     * Salva a edição de uma escala de trabalho inserida manualmente pelo usuário
    **/
    public function saveEdicaoEscalaTrabalho($rows, $nrorg, $cdoperador){
        $this->entityManager->beginTransaction();
        try {
            if(is_array($rows)){
                foreach ($rows as $row) {
                    if(is_array($row["DIASDASEMANA"]))
                        $diasSemana = $row["DIASDASEMANA"];
                    else 
                        $diasSemana = array($row["DIASDASEMANA"]);

                    $diasNAlocados       = array();
                    $nrparcinterlocutor  = null;
                    $nrparcnegrecurso    = $row["NRPARCNEPESSOA"];
                    $nrseqcontrato       = isset($row["NRSEQCONTRATO"]) ? $row["NRSEQCONTRATO"] : $this->getNrContrato($nrrecursosagendcont, $nrorg);
                    $descansoRemunerado  = $row["IDDESCANSOREMU"];
                    $dataInicial         = $row["DTINIAGENDRECURSO"];
                    $dataFinal           = $row["DTFIMAGENDRECURSO"];
                    $newdttrab           = $row["NEWDATATRAB"];
                    $iddiautil           = (empty($row["HRINICIAL"]) || empty($row["HRFINAL"])) ? "N" : $this->verificarDiaUtil($row["DTESCALASAIDA"], $nrseqcontrato, $nrorg);

                    $params = array(
                        "NRRECURSOSAGENDCONT"      => $row["NRRECURSOSAGENDCONT"],
                        "DTESCALASAIDA"            => $row["DTESCALASAIDA"],
                        "DTESCALAENTRADA"          => $row["DTESCALAENTRADA"],
                        "HRINICIAL"                => $row["HRINICIAL"],
                        "HRFINAL"                  => $row["HRFINAL"],
                        "HRINTERVALO"              => $row["HRINTERVALO"],
                        "NRORG"                    => $nrorg
                    );
                            
                    $this->equipeFactory->saveEdicaoEscalaTrabalho($params);
                    if(!empty($row["NRPARCNEPESSOA"])){
                        if(empty($row["HRINICIAL"]) || empty($row["HRFINAL"])){
                            $this->salvarApropiacaoEdicaoEscala($row, $nrorg, $cdoperador, $dataInicial, $dataFinal);
                        } else { 
                            
                            if($row["NEWDATATRAB"])
                                $this->apropriacaoRecursoService->inserirApropriacaoRecurso($row["NRRECURSOSAGENDCONT"], $nrparcnegrecurso, $row["DTESCALAENTRADA"], $nrparcinterlocutor, $nrorg, $cdoperador, implode(",",$diasSemana), $iddiautil);
                        }
                    }
                }            
                $this->entityManager->commit();
            }
        } catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    /**
     * deleta uma escala de trabalho inserida manualmente pelo usuário
    **/
    public function deletarEscala($nrrecursosagendcont, $nrorg, $dtentrada){
        $this->entityManager->beginTransaction();
        try {
            if(is_array($nrrecursosagendcont))
                $nrrecursosagendcont = implode(",", $nrrecursosagendcont);
            $params = array(
                "NRORG" => $nrorg
            );
            $this->equipeFactory->deletarEscala($params, $nrrecursosagendcont);
            $this->apropriacaoRecursoService->deletarApropriacaoRecurso($nrrecursosagendcont, $dtentrada, $nrorg, null, -1);
            $this->entityManager->commit();
        } catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    /**
     * Valida o perído de alocação para verificar se o recurso escolhido
     * esta disponível naquela
    **/
    public function verificaDisponibilidadeRec($rows, $nrorg){
        foreach($rows as $row){
            $chave = $row["CHAVE"];
            
            if(!is_array($row["CHAVE"]))
                $chave = array($row["CHAVE"]);
                
            $chave = implode("','", $chave);
            $params = array(
                "DTENTRADA"           => $row["DTENTRADA"],
                "NRRECURSOSAGENDCONT" => $row["NRRECURSOSAGENDCONT"],
                "NRORG"               => $nrorg
            );
            
            $diadasemana = $row["DIASDASEMANA"];
            $result = $this->equipeFactory->verificaDisponibilidadeRec($params, $diadasemana, $chave);
            if($result[0]["EXISTE"] >= 1)
                return false;
        }
        
        return true;
    }
    
    /**
     * Retorna o número do contrato ligado ao recurso agendado
    **/
    public function getNrContrato($nrrecursosagendcont, $nrorg){
        $params = array(
            "NRRECURSOSAGENDCONT" => $nrrecursosagendcont,
            "NRORG"               => $nrorg
        );
        $result = $this->equipeFactory->getNrContrato($params);
        return !empty($result) ? $result[0]["NRSEQCONTRATO"] : null;
    }
    
    /**
     * Retorna os dias não trabalhados 
     * na escala de trabalho ligada ao agendamento
    **/
    public function getDiasNaotrabalhadosEscala($nrrecursosagendcont, $dtinicioagendamento, $dtfimagendamento, $nrorg){
        $params = array(
            "NRRECURSOSAGENDCONT" => $nrrecursosagendcont,
            "DTINIAGENDAMENTO"    => $dtinicioagendamento,
            "DTFIMAGENDAMENTO"    => $dtfimagendamento,
            "NRORG"               => $nrorg
        );
        
        return $this->equipeFactory->getDiasNaotrabalhadosEscala($params);
    }
    /**
     * Valida se um período de alocação está dentro do outro
    **/
    public function validarPeriodosAlocacao($row, $nrorg) {
        $params = array(
            "NRORG"              => $nrorg,
            "NRAGENDRECURSOCONT" => $row["NRAGENDRECURSOCONT"],
            "NRITEMOCONTRATO"    => $row["NRITEMOCONTRATO"],
            "DTINIAGENDRECURSO"  => $row["DTINIAGENDRECURSO"],
            "DTFIMAGENDRECURSO"  => $row["DTFIMAGENDRECURSO"]
        );
        return $this->equipeFactory->validarPeriodosAlocacao($params);
    }
    /**
     * Valida se o item definido já possue alocação para todos 
     * os dias definidos.
    **/
    public function validarDiasAlocacaoItens($rows, $nrorg) {
        $row          = $rows[0];
        $quantidade   = count($rows);
        $diasDaSemana = array("IDREPETSEGUNDA", "IDREPETTERCA", "IDREPETQUARTA", "IDREPETQUINTA", "IDREPETSEXTA", "IDREPETSABADO", "IDREPETDOMINGO");
        $diasAlocados = $this->validarPeriodosAlocacao($row, $nrorg);
        if(count($diasAlocados) > 0) {
            foreach($diasAlocados as $diaAlocado) {
                $diferenca = ($diaAlocado["QTITEMCONTRATO"] - $diaAlocado["QTALOCADO"]);
                
                if($diferenca != 0 && $diferenca < $quantidade) 
                    return "O item selecionado permite somente a alocação de mais " . $diferenca . " recurso" . ($diferenca > 1 ? "s" : "") ." para o período determinado.";
                
                if($diferenca == 0) {
                    foreach($diasDaSemana as $dia) {
                        if(isset($row[$dia]) && $diaAlocado[$dia] == 'S' && $row[$dia] == 'S')
                            return "O item selecionado já possui a quantidade máxima de alocações para o período definido.";
                    }
                }
            }
        }
        
        return null;
    }
}